pub enum InboundDerivationMessage {
NewDataAvailable,
SafeHeadUpdated,
}Expand description
Messages that the DerivationActor can receive from other actors.
Variants
NewDataAvailable
New data is potentially available for processing on the data availability layer.
SafeHeadUpdated
The engine has updated its safe head. An attempt to process the next payload attributes can be made.