pub enum NetworkActorError {
NetworkBuilder(NetworkBuilderError),
NetworkDriver(NetworkDriverError),
DriverStartup(TransportError<Error>),
MissingUnsafeBlockReceiver,
MissingUnsafeBlockSigner,
ChannelClosed,
FailedToSignPayload(BlockSignerError),
}Expand description
An error from the network actor.
Variants
NetworkBuilder(NetworkBuilderError)
Network builder error.
NetworkDriver(NetworkDriverError)
Network driver error.
DriverStartup(TransportError<Error>)
Driver startup failed.
MissingUnsafeBlockReceiver
The network driver was missing its unsafe block receiver.
MissingUnsafeBlockSigner
The network driver was missing its unsafe block signer sender.
ChannelClosed
Channel closed unexpectedly.
FailedToSignPayload(BlockSignerError)
Failed to sign the payload.