pub struct ConductorClient { /* private fields */ }Expand description
A client for communicating with the conductor service via RPC
Implementations
Sourceimpl ConductorClient
impl ConductorClient
Sourcepub async fn leader(&self) -> Result<bool, ConductorError>
pub async fn leader(&self) -> Result<bool, ConductorError>
Check if the node is a leader of the conductor.
Sourcepub async fn conductor_active(&self) -> Result<bool, ConductorError>
pub async fn conductor_active(&self) -> Result<bool, ConductorError>
Check if the conductor is active.
Sourcepub async fn override_leader(&self) -> Result<(), ConductorError>
pub async fn override_leader(&self) -> Result<(), ConductorError>
Override the leader of the conductor.
Sourcepub async fn commit_unsafe_payload(
&self,
payload: &OpExecutionPayloadEnvelope,
) -> Result<(), ConductorError>
pub async fn commit_unsafe_payload( &self, payload: &OpExecutionPayloadEnvelope, ) -> Result<(), ConductorError>
Commit an unsafe payload to the conductor.