Struct DerivationActor

pub struct DerivationActor<B>
where B: PipelineBuilder,
{ /* private fields */ }
The NodeActor for the derivation sub-routine.

This actor is responsible for receiving messages from NodeActors and stepping the derivation pipeline forward to produce new payload attributes. The actor then sends the payload to the NodeActor responsible for the execution sub-routine.

Implementations

Source

impl<B> DerivationActor<B>
where B: PipelineBuilder,

pub fn new(state: B) -> (DerivationInboundChannels, Self)

Creates a new instance of the DerivationActor.