pub struct DerivationInboundChannels {
pub l1_head_updates_tx: Sender<Option<BlockInfo>>,
pub engine_l2_safe_head_tx: Sender<L2BlockInfo>,
pub el_sync_complete_tx: Sender<()>,
pub derivation_signal_tx: Sender<Signal>,
}Expand description
The inbound channels for the derivation actor. These channels are used to send messages to the derivation actor by other actors.
Fields
l1_head_updates_tx: Sender<Option<BlockInfo>>The sender for L1 head update notifications.
engine_l2_safe_head_tx: Sender<L2BlockInfo>The sender for L2 safe head update notifications.
el_sync_complete_tx: Sender<()>A sender used by the engine to signal derivation to begin. Completing EL sync consumes the instance.
derivation_signal_tx: Sender<Signal>A sender that sends a Signal to the derivation pipeline.
This channel should be used by the engine actor to send Signals to the derivation
pipeline. The signals are received by DerivationActor::derivation_signal_rx.