pub struct DerivationState<P>where
P: Pipeline + SignalReceiver,{
pub pipeline: P,
pub derivation_idle: bool,
pub waiting_for_signal: bool,
}Expand description
The state for the derivation actor.
Fields
pipeline: PThe derivation pipeline.
derivation_idle: boolA flag indicating whether or not derivation is idle. Derivation is considered idle when it has yielded to wait for more data on the DAL.
waiting_for_signal: boolA flag indicating whether or not derivation is waiting for a signal. When waiting for a signal, derivation cannot process any incoming events.
Implementations
Sourceimpl<P> DerivationState<P>where
P: Pipeline + SignalReceiver,
impl<P> DerivationState<P>where
P: Pipeline + SignalReceiver,
Sourcepub const fn new(pipeline: P) -> Self
pub const fn new(pipeline: P) -> Self
Creates a new instance of the DerivationState.