Struct EngineActor

pub struct EngineActor { /* private fields */ }
The EngineActor is responsible for managing the operations sent to the execution layer’s Engine API. To accomplish this, it uses the Engine task queue to order Engine API interactions based off of the Ord implementation of EngineTask.

Implementations

Source

impl EngineActor

pub fn new(config: EngineBuilder) -> (EngineInboundData, Self)

Constructs a new EngineActor from the params.