Struct EngineBuilder

pub struct EngineBuilder {
    pub config: Arc<RollupConfig>,
    pub engine_url: Url,
    pub l1_rpc_url: Url,
    pub jwt_secret: JwtSecret,
    pub mode: NodeMode,
}
Configuration for the Engine Actor.

Fields

config: Arc<RollupConfig>engine_url: Url

The engine rpc url.

l1_rpc_url: Url

The L1 rpc url.

jwt_secret: JwtSecret

The engine jwt secret.

mode: NodeMode

The mode of operation for the node. When the node is in sequencer mode, the engine actor will receive requests to build blocks from the sequencer actor.

Implementations