Struct EngineContext

pub struct EngineContext {
    pub cancellation: CancellationToken,
    pub engine_unsafe_head_tx: Option<Sender<L2BlockInfo>>,
    pub engine_l2_safe_head_tx: Sender<L2BlockInfo>,
    pub sync_complete_tx: Sender<()>,
    pub derivation_signal_tx: Sender<Signal>,
}
The communication context used by the engine actor.

Fields

cancellation: CancellationToken

The cancellation token, shared between all tasks.

engine_unsafe_head_tx: Option<Sender<L2BlockInfo>>

A sender for L2 unsafe head update notifications. Is optional because it is only used in sequencer mode.

engine_l2_safe_head_tx: Sender<L2BlockInfo>

The sender for L2 safe head update notifications.

sync_complete_tx: Sender<()>

A channel to send a signal that EL sync has completed. Informs the derivation actor to start. Because the EL sync state machine within InnerEngineState can only complete once, this channel is consumed after the first successful send. Future cases where EL sync is re-triggered can occur, but we will not block derivation on it.

derivation_signal_tx: Sender<Signal>

A way for the engine actor to send a Signal back to the derivation actor.