pub struct Metrics;Expand description
Container for metrics.
Implementations
Sourceimpl Metrics
impl Metrics
Sourcepub const L1_REORG_COUNT: &str = "kona_node_l1_reorg_count"
pub const L1_REORG_COUNT: &str = "kona_node_l1_reorg_count"
Identifier for the counter that tracks the number of times the L1 has reorganized.
Sourcepub const DERIVATION_L1_ORIGIN: &str = "kona_node_derivation_l1_origin"
pub const DERIVATION_L1_ORIGIN: &str = "kona_node_derivation_l1_origin"
Identifier for the counter that tracks the L1 origin of the derivation pipeline.
Sourcepub const DERIVATION_CRITICAL_ERROR: &str = "kona_node_derivation_critical_errors"
pub const DERIVATION_CRITICAL_ERROR: &str = "kona_node_derivation_critical_errors"
Identifier for the counter of critical derivation errors (strictly for alerting.)
Sourcepub const SEQUENCER_STATE: &str = "kona_node_sequencer_state"
pub const SEQUENCER_STATE: &str = "kona_node_sequencer_state"
Identifier for the counter that tracks sequencer state flags.
Sourcepub const SEQUENCER_ATTRIBUTES_BUILDER_DURATION: &str = "kona_node_sequencer_attributes_build_duration"
pub const SEQUENCER_ATTRIBUTES_BUILDER_DURATION: &str = "kona_node_sequencer_attributes_build_duration"
Gauge for the sequencer’s attributes builder duration.
Sourcepub const SEQUENCER_BLOCK_BUILDING_JOB_DURATION: &str = "kona_node_sequencer_block_building_duration"
pub const SEQUENCER_BLOCK_BUILDING_JOB_DURATION: &str = "kona_node_sequencer_block_building_duration"
Gauge for the sequencer’s block building job duration.
Sourcepub const SEQUENCER_CONDUCTOR_COMMITMENT_DURATION: &str = "kona_node_sequencer_conductor_commitment_duration"
pub const SEQUENCER_CONDUCTOR_COMMITMENT_DURATION: &str = "kona_node_sequencer_conductor_commitment_duration"
Gauge for the sequencer’s conductor commitment duration.