Struct NetworkActor

pub struct NetworkActor { /* private fields */ }
The network actor handles two core networking components of the rollup node:

  • discovery: Peer discovery over UDP using discv5.
  • gossip: Block gossip over TCP using libp2p.

The network actor itself is a light wrapper around the NetworkBuilder.

Example

use kona_p2p::NetworkDriver;
use std::net::{IpAddr, Ipv4Addr, SocketAddr};

let chain_id = 10;
let signer = Address::random();
let socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::UNSPECIFIED), 9099);

// Construct the `Network` using the builder.
// let mut driver = Network::builder()
//    .with_unsafe_block_signer(signer)
//    .with_chain_id(chain_id)
//    .with_gossip_addr(socket)
//    .build()
//    .unwrap();

// Construct the `NetworkActor` with the [`Network`].
// let actor = NetworkActor::new(driver);

Implementations

Source

impl NetworkActor

pub fn new(driver: NetworkBuilder) -> (NetworkInboundData, Self)

Constructs a new NetworkActor given the NetworkBuilder