pub struct NetworkDriver {
pub gossip: GossipDriver<ConnectionGater>,
pub discovery: Discv5Driver,
pub unsafe_block_signer_sender: Sender<Address>,
pub signer: Option<BlockSigner>,
}Expand description
A network driver. This is the driver that is used to start the network.
Fields
gossip: GossipDriver<ConnectionGater>The gossip driver.
discovery: Discv5DriverThe discovery driver.
unsafe_block_signer_sender: Sender<Address>The unsafe block signer sender.
signer: Option<BlockSigner>A block signer. This is optional and should be set if the node is configured to sign blocks
Implementations
Sourceimpl NetworkDriver
impl NetworkDriver
Sourcepub async fn start(self) -> Result<NetworkHandler, NetworkDriverError>
pub async fn start(self) -> Result<NetworkHandler, NetworkDriverError>
Starts the network.