pub struct NetworkHandler {
pub gossip: GossipDriver<ConnectionGater>,
pub discovery: Discv5Handler,
pub enr_receiver: Receiver<Enr>,
pub unsafe_block_signer_sender: Sender<Address>,
pub peer_score_inspector: Interval,
pub signer: Option<BlockSignerHandler>,
}Expand description
A network handler used to communicate with the network once it is started.
Fields
gossip: GossipDriver<ConnectionGater>The gossip driver.
discovery: Discv5HandlerThe discovery handler.
enr_receiver: Receiver<Enr>The receiver for the ENRs.
unsafe_block_signer_sender: Sender<Address>The sender for the unsafe block signer.
peer_score_inspector: IntervalThe peer score inspector. Is used to ban peers that are below a given threshold.
signer: Option<BlockSignerHandler>A handler for the block signer.