pub struct NetworkInboundData {
pub signer: Sender<Address>,
pub p2p_rpc: Sender<P2pRpcRequest>,
pub admin_rpc: Sender<NetworkAdminQuery>,
pub gossip_payload_tx: Sender<OpExecutionPayloadEnvelope>,
}Expand description
The inbound data for the network actor.
Fields
signer: Sender<Address>A channel to send the unsafe block signer address to the network actor.
p2p_rpc: Sender<P2pRpcRequest>Handler for p2p RPC Requests sent to the network actor.
admin_rpc: Sender<NetworkAdminQuery>Handler for admin RPC Requests.
gossip_payload_tx: Sender<OpExecutionPayloadEnvelope>A channel to send unsafe blocks to the network actor. This channel should only be used by the sequencer actor/admin RPC api to forward their newly produced unsafe blocks to the network actor.