Struct SequencerConfig

pub struct SequencerConfig {
    pub sequencer_stopped: bool,
    pub sequencer_recovery_mode: bool,
    pub conductor_rpc_url: Option<Url>,
    pub l1_conf_delay: u64,
}
Configuration for the SequencerActor.

Fields

sequencer_stopped: bool

Whether or not the sequencer is enabled at startup.

sequencer_recovery_mode: bool

Whether or not the sequencer is in recovery mode.

conductor_rpc_url: Option<Url>

The Url for the conductor RPC endpoint. If Some, enables the conductor service.

l1_conf_delay: u64

The confirmation delay for the sequencer.