pub struct SequencerContext {
pub cancellation: CancellationToken,
pub l1_head_rx: Receiver<Option<BlockInfo>>,
pub reset_request_tx: Sender<()>,
pub build_request_tx: Sender<(OpAttributesWithParent, Sender<OpExecutionPayloadEnvelope>)>,
pub gossip_payload_tx: Sender<OpExecutionPayloadEnvelope>,
}Expand description
The communication context used by the SequencerActor.
Fields
cancellation: CancellationTokenThe cancellation token, shared between all tasks.
l1_head_rx: Receiver<Option<BlockInfo>>Watch channel to observe the L1 head of the chain.
reset_request_tx: Sender<()>Sender to request the engine to reset.
build_request_tx: Sender<(OpAttributesWithParent, Sender<OpExecutionPayloadEnvelope>)>Sender to request the execution layer to build a payload attributes on top of the current unsafe head.
gossip_payload_tx: Sender<OpExecutionPayloadEnvelope>A sender to asynchronously sign and gossip built OpExecutionPayloadEnvelopes to the
network actor.