pub struct SequencerInboundData {
pub unsafe_head_tx: Sender<L2BlockInfo>,
pub admin_query_tx: Sender<SequencerAdminQuery>,
}Expand description
The inbound channels for the SequencerActor.
These channels are used by external actors to send messages to the sequencer actor.
Fields
unsafe_head_tx: Sender<L2BlockInfo>Watch channel to observe the unsafe head of the engine.
admin_query_tx: Sender<SequencerAdminQuery>Channel to send admin queries to the sequencer actor.