pub struct EngineActor { /* private fields */ }Expand description
The EngineActor is responsible for managing the operations sent to the execution layer’s
Engine API. To accomplish this, it uses the Engine task queue to order Engine API
interactions based off of the Ord implementation of EngineTask.
Implementations
Sourceimpl EngineActor
impl EngineActor
Sourcepub fn new(config: EngineBuilder) -> (EngineInboundData, Self)
pub fn new(config: EngineBuilder) -> (EngineInboundData, Self)
Constructs a new EngineActor from the params.