pub struct EngineBuilder {
pub config: Arc<RollupConfig>,
pub engine_url: Url,
pub l1_rpc_url: Url,
pub jwt_secret: JwtSecret,
pub mode: NodeMode,
}Expand description
Configuration for the Engine Actor.
Fields
config: Arc<RollupConfig>The RollupConfig.
engine_url: UrlThe engine rpc url.
l1_rpc_url: UrlThe L1 rpc url.
jwt_secret: JwtSecretThe engine jwt secret.
mode: NodeModeThe mode of operation for the node. When the node is in sequencer mode, the engine actor will receive requests to build blocks from the sequencer actor.
Implementations
Sourceimpl EngineBuilder
impl EngineBuilder
Sourcepub fn client(&self) -> Arc<EngineClient>
pub fn client(&self) -> Arc<EngineClient>
Returns the EngineClient.