pub struct EngineInboundData {
pub build_request_tx: Option<Sender<(OpAttributesWithParent, Sender<OpExecutionPayloadEnvelope>)>>,
pub attributes_tx: Sender<OpAttributesWithParent>,
pub unsafe_block_tx: Sender<OpExecutionPayloadEnvelope>,
pub reset_request_tx: Sender<()>,
pub inbound_queries_tx: Sender<EngineQueries>,
pub finalized_l1_block_tx: Sender<Option<BlockInfo>>,
}Expand description
The outbound data for the EngineActor.
Fields
build_request_tx: Option<Sender<(OpAttributesWithParent, Sender<OpExecutionPayloadEnvelope>)>>The channel used by the sequencer actor to send build requests to the engine actor.
Note
This is Some when the node is in sequencer mode, and None when the node is in validator
mode.
attributes_tx: Sender<OpAttributesWithParent>A channel to send OpAttributesWithParent to the engine actor.
unsafe_block_tx: Sender<OpExecutionPayloadEnvelope>A channel to send OpExecutionPayloadEnvelope to the engine actor.
Note
The sequencer actor should not need to send OpExecutionPayloadEnvelopes to the engine
actor through that channel. Instead, it should use the build_request_tx channel to
trigger BuildTask tasks which should insert the block newly built to the engine
state upon completion.
reset_request_tx: Sender<()>A channel to send reset requests.
inbound_queries_tx: Sender<EngineQueries>Handler to send inbound queries to the engine.
finalized_l1_block_tx: Sender<Option<BlockInfo>>A channel that sends new finalized L1 blocks intermittently.