pub struct L1OriginSelector<P: L1OriginSelectorProvider> { /* private fields */ }Expand description
The L1OriginSelector is responsible for selecting the L1 origin block based on the
current L2 unsafe head’s sequence epoch.
Implementations
Sourceimpl<P: L1OriginSelectorProvider> L1OriginSelector<P>
impl<P: L1OriginSelectorProvider> L1OriginSelector<P>
Sourcepub const fn new(cfg: Arc<RollupConfig>, l1: P) -> Self
pub const fn new(cfg: Arc<RollupConfig>, l1: P) -> Self
Creates a new L1OriginSelector.
Sourcepub async fn next_l1_origin(
&mut self,
unsafe_head: L2BlockInfo,
is_recovery_mode: bool,
) -> Result<BlockInfo, L1OriginSelectorError>
pub async fn next_l1_origin( &mut self, unsafe_head: L2BlockInfo, is_recovery_mode: bool, ) -> Result<BlockInfo, L1OriginSelectorError>
Determines what the next L1 origin block should be, based off of the L2BlockInfo unsafe
head.
The L1 origin is selected based off of the sequencing epoch, determined by the next L2 block’s timestamp in relation to the current L1 origin’s timestamp. If the next L2 block’s timestamp is greater than the L2 unsafe head’s L1 origin timestamp, the L1 origin is the block following the current L1 origin.