pub struct SequencerActor<AB: AttributesBuilderConfig> {
pub builder: AB,
pub unsafe_head_rx: Receiver<L2BlockInfo>,
pub admin_query_rx: Receiver<SequencerAdminQuery>,
}Expand description
The SequencerActor is responsible for building L2 blocks on top of the current unsafe head
and scheduling them to be signed and gossipped by the P2P layer, extending the L2 chain with new
blocks.
Fields
builder: ABunsafe_head_rx: Receiver<L2BlockInfo>Watch channel to observe the unsafe head of the engine.
admin_query_rx: Receiver<SequencerAdminQuery>Channel to receive admin queries from the sequencer actor.
Implementations
Sourceimpl<AB: AttributesBuilderConfig> SequencerActor<AB>
impl<AB: AttributesBuilderConfig> SequencerActor<AB>
Sourcepub fn new(state: AB) -> (SequencerInboundData, Self)
pub fn new(state: AB) -> (SequencerInboundData, Self)
Creates a new instance of the SequencerActor.