pub struct SequencerConfig {
pub sequencer_stopped: bool,
pub sequencer_recovery_mode: bool,
pub conductor_rpc_url: Option<Url>,
pub l1_conf_delay: u64,
}Expand description
Configuration for the SequencerActor.
Fields
sequencer_stopped: boolWhether or not the sequencer is enabled at startup.
sequencer_recovery_mode: boolWhether or not the sequencer is in recovery mode.
conductor_rpc_url: Option<Url>l1_conf_delay: u64The confirmation delay for the sequencer.